@@ -9,13 +9,15 @@
 #' or [`terra`][terra::SpatRaster] object to serve as a template for cropping.
 #' @param label A character string naming the study area.
 #' @param year An integer representing the year of desired NLCD product.
-#' Acceptable values are 2021 (default), 2019, 2016, 2011, 2008, 2006, 2004, and 2001.
+#' Acceptable values are 2019 (default), 2016, 2011, 2008, 2006, 2004, and 2001.
+#' The L48 data set for 2021 is corrupted on the NLCD Mapserver, and is thus
+#' not available through FedData.
 #' @param dataset A character string representing type of the NLCD product.
 #' Acceptable values are 'landcover' (default), 'impervious', and
 #' 'canopy'.
 #' @param landmass A character string representing the landmass to be extracted
 #' Acceptable values are 'L48' (lower 48 US states, the default),
-#' 'AK' (Alaska, 2011 and 2016 only), 'HI' (Hawaii, 2001 only), and
+#' 'AK' (Alaska, 2001, 2011 and 2016 only), 'HI' (Hawaii, 2001 only), and
 #' 'PR' (Puerto Rico, 2001 only).
 #' @param extraction.dir A character string indicating where the extracted
 #' and cropped NLCD data should be put. The directory will be created if missing.
@@ -61,22 +63,24 @@ get_nlcd <- function(template,
   extraction.dir <-
     normalizePath(paste0(extraction.dir, "/."), mustWork = FALSE)
 
-  tmp <- tempfile(fileext = ".tif")
+  template %<>%
+    template_to_sf()
 
-  template %<>% template_to_sf()
+  dataset <-
+    match.arg(dataset,
+      choices = c(
+        "landcover",
+        "impervious",
+        "canopy"
+      )
+    )
 
-  dataset <- match.arg(dataset,
-    choices = c(
-      "landcover",
-      "impervious",
-      "canopy"
+  dataset <-
+    switch(dataset,
+      landcover = "Land_Cover",
+      impervious = "Impervious",
+      canopy = "Tree_Canopy"
     )
-  )
-  dataset <- switch(dataset,
-    landcover = "Land_Cover",
-    impervious = "Impervious",
-    canopy = "Tree_Canopy"
-  )
 
   dir.create(extraction.dir, showWarnings = FALSE, recursive = TRUE)
 
@@ -87,138 +91,97 @@ get_nlcd <- function(template,
     return(terra::rast(outfile))
   }
 
-  src <- "wcs"
+  nlcd_base_url <-
+    "https://www.mrlc.gov/geoserver/ows"
 
-  if (src == "wcs") {
-    if (dataset == "Tree_Canopy" & landmass == "L48") {
-      # Because MRLC did an update, and of course they didn't use the same naming convention
-      coverage <- paste0("nlcd_tcc_conus_", year, "_v2021-4")
-      source <- paste0("https://www.mrlc.gov/geoserver/mrlc_download/", coverage, "/wcs")
-    } else {
-      coverage <- paste0("NLCD_", year, "_", dataset, "_", landmass)
-      source <- paste0("https://www.mrlc.gov/geoserver/mrlc_download/", coverage, "/wcs")
-    }
+  if (dataset == "Tree_Canopy" & landmass == "L48") {
+    # Because MRLC did an update, and of course they didn't use the same naming convention
+    coverage <- paste0("mrlc_download__nlcd_tcc_conus_", year, "_v2021-4")
+  } else {
+    coverage <- paste0("mrlc_download__NLCD_", year, "_", dataset, "_", landmass)
+  }
 
 
 
-    # This code uses the (oft-changing) MRLC web services.
-    if (source %>%
-      httr::GET(query = list(
-        service = "WCS",
-        version = "2.0.1",
-        request = "DescribeCoverage",
-        coverageid = coverage
-      )) %>%
-      httr::status_code() %>%
-      identical(200L) %>%
-      magrittr::not()) {
-      stop("No web coverage service at ", source, ". See available services at https://www.mrlc.gov/geoserver/ows?service=WCS&version=2.0.1&request=GetCapabilities")
-    }
+  # This code uses the (oft-changing) MRLC web services.
+  if (nlcd_base_url %>%
+    httr::GET(query = list(
+      service = "WCS",
+      version = "2.0.1",
+      request = "DescribeCoverage",
+      coverageid = coverage
+    )) %>%
+    httr::status_code() %>%
+    identical(200L) %>%
+    magrittr::not()) {
+    stop(
+      "No web coverage service at ",
+      source, ". See available services at ",
+      nlcd_base_url, "?service=WCS&version=2.0.1&request=GetCapabilities"
+    )
+  }
 
-    template %<>%
-      sf::st_transform("+proj=aea +lat_0=23 +lon_0=-96 +lat_1=29.5 +lat_2=45.5 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs") %>%
-      # sf::st_transform(3857) %>%
-      sf::st_bbox()
-
-    axis_labels <-
-      source %>%
-      httr::GET(
-        query = list(
-          service = "WCS",
+  source <-
+    httr::modify_url(
+      nlcd_base_url,
+      query =
+        list(
           version = "2.0.1",
-          request = "DescribeCoverage",
           coverageid = coverage
         )
-      ) %>%
-      httr::content(encoding = "UTF-8") %>%
-      xml2::as_list() %$%
-      CoverageDescriptions %$%
-      CoverageDescription$boundedBy$Envelope %>%
-      attr("axisLabels") %>%
-      stringr::str_split(" ") %>%
-      unlist()
+    )
 
-    source %>%
-      httr::GET(
-        query = list(
-          service = "WCS",
-          version = "2.0.1",
-          request = "GetCoverage",
-          coverageid = coverage,
-          subset = paste0(axis_labels[[1]], "(", template["xmin"], ",", template["xmax"], ")"),
-          subset = paste0(axis_labels[[2]], "(", template["ymin"], ",", template["ymax"], ")")
-        ),
-        httr::write_disk(
-          path = tmp,
-          overwrite = TRUE
+  out <-
+    tryCatch(
+      paste0("WCS:", source) |>
+        terra::rast(),
+      error = function(e) {
+        stop(
+          "Web coverage service at ",
+          source, " is corrupted. You may have better luck downloading the file at https://www.mrlc.gov/data."
         )
-      )
-  }
+      }
+    )
 
-
-  if (src == "cog") {
-    source <- "https://storage.googleapis.com/feddata-r/nlcd/"
-    file <- paste0(year, "_", dataset, "_", landmass, ".tif")
-
-    path <- paste0(source, file)
-
-    if (path %>%
-      httr::HEAD() %>%
-      httr::status_code() %>%
-      identical(200L) %>%
-      magrittr::not()) {
-      stop(
-        "NLCD data are not available for dataset '", dataset, "', year '", year,
-        "', and landmass '", landmass,
-        "'. Please see available datasets at https://www.mrlc.gov/data."
-      )
-    }
-
-    template %<>%
-      template_to_sf()
-
-    out <-
-      paste0("/vsicurl/", path) %>%
-      terra::rast() %>%
-      terra::crop(.,
-        sf::st_transform(template, sf::st_crs(terra::crs(.))),
-        snap = "out",
-        filename = outfile,
-        datatype = "INT1U",
-        gdal = raster.options,
-        overwrite = TRUE
-      )
-  }
+  out <-
+    out |>
+    terra::crop(
+      sf::st_transform(
+        template,
+        terra::crs(out)
+      ) |>
+        terra::vect(),
+      snap = "out",
+      mask = TRUE
+    ) |>
+    magrittr::set_names(coverage)
 
   if (dataset == "Land_Cover") {
     out <-
-      tmp %>%
-      terra::rast() %>%
+      out |>
       terra::as.factor()
 
     levels(out) <-
       nlcd_colors() %>%
       as.data.frame()
 
-    terra::coltab(out) %<>%
-      magrittr::extract2(1) %>%
-      dplyr::filter(value %in% nlcd_colors()$ID)
-
-    terra::writeRaster(
-      x = out,
-      filename = outfile,
-      datatype = "INT1U",
-      gdal = raster.options,
-      overwrite = TRUE
-    )
-  } else {
-    file.copy(
-      from = tmp,
-      to = outfile,
-      overwrite = TRUE
-    )
+    terra::coltab(out) <-
+      nlcd_colors() |>
+      dplyr::transmute(
+        value = as.integer(ID),
+        color = Color
+      ) |>
+      as.data.frame()
   }
 
+  terra::writeRaster(
+    x = out,
+    filename = outfile,
+    datatype = "INT1U",
+    gdal = raster.options,
+    overwrite = TRUE
+  )
+
   return(terra::rast(outfile))
 }
 
@@ -576,3 +539,79 @@ nlcd_colors <- function() {
 pal_nlcd <- function() {
   stats::na.omit(nlcd)
 }
+
+list_nlcd <-
+  function() {
+    (httr::GET(
+      "https://www.mrlc.gov/geoserver/ows",
+      query = list(
+        service = "WCS",
+        acceptversions = "2.0.1",
+        request = "GetCapabilities"
+      )
+    ) |>
+      httr::content() |>
+      xml2::as_list())$Capabilities$Contents |>
+      purrr::map(\(x)
+      list(
+        Title = x$Title[[1]],
+        id = x$CoverageId[[1]]
+      )) |>
+      magrittr::set_names(NULL) |>
+      purrr::transpose() |>
+      purrr::map(unlist) |>
+      tibble::as_tibble() |>
+      dplyr::filter(
+        stringr::str_starts(id, "mrlc_download"),
+        stringr::str_detect(id, "NLCD|nlcd"),
+        stringr::str_detect(id, "Science_Product", negate = TRUE),
+        stringr::str_detect(id, "Disturbance_Date", negate = TRUE),
+        stringr::str_detect(id, "Fractional_Component", negate = TRUE),
+        stringr::str_detect(id, "descriptor", negate = TRUE),
+        stringr::str_detect(id, "Descriptor", negate = TRUE),
+        stringr::str_detect(id, "Pixels", negate = TRUE),
+        stringr::str_detect(id, "Annual_NLCD", negate = TRUE),
+        stringr::str_detect(id, "Count", negate = TRUE),
+        stringr::str_detect(id, "Index", negate = TRUE)
+      ) |>
+      dplyr::mutate(
+        Title = stringr::str_replace(
+          Title,
+          "nlcd_tcc_conus",
+          "NLCD"
+        ),
+        Title = stringr::str_replace(
+          Title,
+          "v2021-4",
+          "Tree_Canopy_L48"
+        ),
+        Title = stringr::str_replace(
+          Title,
+          "Land_Cover",
+          "landcover"
+        ),
+        Title = stringr::str_replace(
+          Title,
+          "Impervious",
+          "impervious"
+        ),
+        Title = stringr::str_replace(
+          Title,
+          "Tree_Canopy",
+          "canopy"
+        )
+      ) |>
+      tidyr::separate_wider_delim(
+        cols = Title,
+        delim = "_",
+        names = c(
+          "NLCD",
+          "year",
+          "dataset",
+          "landmass"
+        )
+      ) |>
+      dplyr::select(!NLCD) |>
+      dplyr::arrange(landmass, dataset, year) |>
+      print(n = 200)
+  }
